var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "ClientResources", "../../_generated/ExtensionDefinition", "../../_generated/BladeReferences", "Fx/Composition/Pdl/MenuBlade"], function (require, exports, ClientResources, ExtensionDefinition, BladeReferences, FxMenuBlade) {
    "use strict";
    var FxImages = MsPortalFx.Base.Images;
    "use strict";
    var BillingMenuBladeViewModel = (function (_super) {
        __extends(BillingMenuBladeViewModel, _super);
        function BillingMenuBladeViewModel(container, initialState, dataContext) {
            _super.call(this, container);
            this.id = ko.observable();
            this.subscriptionId = ko.observable();
            this.location = ko.observable("local");
            this.isInvoiceEnabledForTenant = ko.observable(true);
            this.isNotificationsEnabledForTenant = ko.observable(true);
            this.showOnlyAzureStackQuotaBlades = ko.observable(false);
            this.isAzSQuotaCollectorEnabled = ko.observable(false);
            this.assetType = ko.observable(ExtensionDefinition.AssetTypeNames.billing);
            this.assetOwner = ko.observable(ExtensionDefinition.definitionName);
            this.invoicesMenuItem = {
                id: "Invoices",
                displayText: "Invoices",
                icon: FxImages.Polychromatic.OperationalInsights(),
                supplyBladeReference: function () {
                    return new BladeReferences.InvoicesCollectionBladeReference();
                }
            };
            this.notificationMessageMenuItem = {
                id: "Messages",
                displayText: "Messages",
                icon: FxImages.Message(),
                supplyBladeReference: function () {
                    return new BladeReferences.NotificationMessagesBladeReference();
                }
            };
            this.notificationRulesMenuItem = {
                id: "Rules",
                displayText: "Rules",
                icon: FxImages.Tasks(),
                supplyBladeReference: function () {
                    return new BladeReferences.NotificationRulesBladeReference();
                }
            };
            this.quotaStatusOverviewMenuItem = {
                id: "QuotaStatusOverview",
                displayText: "Overview",
                icon: FxImages.Polychromatic.OperationalInsights(),
                supplyBladeReference: function () {
                    return new BladeReferences.UsageAndQuotaStatusBladeReference();
                }
            };
            this.quotaSnapInMenuItem = {
                id: "MonthlySummary",
                displayText: "Monthly Summary",
                icon: FxImages.Polychromatic.ControlsHorizontal(),
                supplyBladeReference: function () {
                    return new BladeReferences.UsageAndQuotaSnapInBladeReference();
                }
            };
            this.quotaTrendMenuItem = {
                id: "TrendReport",
                displayText: "Trend Report",
                icon: FxImages.Polychromatic.Chart(),
                supplyBladeReference: function () {
                    return new BladeReferences.UsageAndQuotaTrendBladeReference();
                }
            };
            this.billingMenuGroups = [
                {
                    id: "BillingAccount",
                    displayText: "Billing Account",
                    items: [
                        {
                            id: "UsageHistory",
                            displayText: "Usage History",
                            icon: FxImages.Polychromatic.Clock(),
                            supplyBladeReference: function () {
                                return new BladeReferences.UsageHistoryBladeReference();
                            }
                        },
                        this.invoicesMenuItem,
                    ]
                },
                {
                    id: "Notifications",
                    displayText: "Notifications",
                    items: [
                        this.notificationMessageMenuItem,
                        this.notificationRulesMenuItem,
                    ]
                },
                {
                    id: "UsageAndQuota",
                    displayText: "Usage + Quota",
                    items: [
                        this.quotaStatusOverviewMenuItem,
                        this.quotaSnapInMenuItem,
                        this.quotaTrendMenuItem,
                    ]
                }
            ];
            this.title(ClientResources.Assets.Billing.singular);
            this.icon(MsPortalFx.Base.Images.Polychromatic.BillingHub());
            this._dataContext = dataContext;
            this._enabledFeaturesEntityView = this._dataContext.sharedContext.licenseManager.enabledFeaturesEntity.createView(container, {
                interceptNotFound: false
            });
            this.menu.groups(this.billingMenuGroups);
            this.menu.groupSortOrder = 0;
            this.menu.groupSortFunction = FxMenuBlade.SortFunction.SupportFirst;
        }
        BillingMenuBladeViewModel.prototype._setInvoiceSettings = function (productFeatures) {
            var isInvoiceEnabled = productFeatures.first(function (feature) { return feature.Name() == "TenantInvoice"; });
            var isNotificationsEnabled = productFeatures.first(function (feature) { return feature.Name() == "Notifications"; });
            if (isInvoiceEnabled != null) {
                this.isInvoiceEnabledForTenant(true);
            }
            else {
                this.isInvoiceEnabledForTenant(false);
            }
            if (isNotificationsEnabled != null) {
                this.isNotificationsEnabledForTenant(true);
            }
            else {
                this.isNotificationsEnabledForTenant(false);
            }
        };
        BillingMenuBladeViewModel.prototype._checkQuotaSettings = function (dataEntity) {
            if (dataEntity.Settings()["IsAzureStackQuotaCollectorAvailable"] != undefined
                && dataEntity.Settings()["IsAzureStackQuotaCollectorAvailable"]() == "True") {
                this.isAzSQuotaCollectorEnabled(true);
            }
            else {
                this.isAzSQuotaCollectorEnabled(false);
            }
            if (dataEntity.Settings()["ShowOnlyAzureStackQuotaBlades"] != undefined
                && dataEntity.Settings()["ShowOnlyAzureStackQuotaBlades"]() == "True") {
                this.showOnlyAzureStackQuotaBlades(true);
            }
            else {
                this.showOnlyAzureStackQuotaBlades(false);
            }
        };
        BillingMenuBladeViewModel.prototype._getInvoiceSettings = function () {
            var _this = this;
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            this._enabledFeaturesEntityView.fetch(args).then(function () {
                var dataEntity = _this._enabledFeaturesEntityView.item();
                _this._checkQuotaSettings(dataEntity);
                _this._setInvoiceSettings(dataEntity.EnabledFeatures());
                if (_this.isAzSQuotaCollectorEnabled()) {
                    if (_this.showOnlyAzureStackQuotaBlades()) {
                        var usageGroup = [];
                        usageGroup.push(_this.billingMenuGroups.first(function (i) { return i.id == "UsageAndQuota"; }));
                        _this.menu.groups(usageGroup);
                        _this.menu.setOptions({
                            defaultId: "QuotaStatusOverview",
                        });
                    }
                    else {
                        _this._showOrHideBlades();
                    }
                }
                else {
                    var index = _this.billingMenuGroups.firstIndex(function (x) { return x.id == "UsageAndQuota"; });
                    _this.billingMenuGroups.splice(index, 1);
                    _this.menu.groups(_this.billingMenuGroups);
                    _this._showOrHideBlades();
                }
            });
        };
        BillingMenuBladeViewModel.prototype._showOrHideBlades = function () {
            if (!this.isInvoiceEnabledForTenant()) {
                var index = this.billingMenuGroups[0].items.indexOf(this.invoicesMenuItem);
                this.billingMenuGroups[0].items.splice(index, 1);
                this.menu.groups(this.billingMenuGroups);
            }
            if (!this.isNotificationsEnabledForTenant()) {
                var index = this.billingMenuGroups.indexOf(this.billingMenuGroups.first(function (x) { return x.id == "Notifications"; }));
                this.billingMenuGroups.splice(index, 1);
                this.menu.groups(this.billingMenuGroups);
            }
            this.menu.setOptions({
                overview: {
                    id: "Overview",
                    displayText: "Overview",
                    icon: FxImages.Polychromatic.BillingHub(),
                    supplyBladeReference: function () {
                        return new BladeReferences.BillingOverviewBladeReference({
                            id: 'balhBlah/blahBalh'
                        });
                    }
                }
            });
        };
        BillingMenuBladeViewModel.prototype._getFirstSubscription = function () {
            var _this = this;
            this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                _this.subscriptionId(subscriptions.first().subscriptionId);
            }).finally(function () {
                _this._getInvoiceSettings();
            });
        };
        BillingMenuBladeViewModel.prototype.onInputsSet = function (inputs) {
            this.id(inputs.id);
            this._getFirstSubscription();
            return Q();
        };
        return BillingMenuBladeViewModel;
    }(FxMenuBlade.ViewModel));
    exports.BillingMenuBladeViewModel = BillingMenuBladeViewModel;
});
