define(["require", "exports", "../../Shared/Helpers", "MsPortalFx/Globalization"], function (require, exports, Helpers, Globalization) {
    "use strict";
    var FxChart = MsPortalFx.ViewModels.Controls.Visualization.Chart;
    var Def = {};
    var LineChartDateBasedPartViewModel = (function () {
        function LineChartDateBasedPartViewModel(container, initialState, dataContext) {
            var _this = this;
            this.vmId = ko.observable();
            this.vmCpuDataSeries = ko.observable();
            this._useMetricRuleOptions = true;
            var yAxisNumberFormatOptions = { minimumFractionDigits: 0, maximumFractionDigits: 2 };
            this._dataContext = dataContext;
            this.lineChartVM = new FxChart.ViewModel(container);
            var view = new FxChart.LineChartView();
            this.lineChartVM.views([view]);
            this.lineChartVM.legendPosition(1);
            this.lineChartVM.xAxis.scale(2);
            this.lineChartVM.yAxis.unit(MsPortalFx.UnitConversion.Unit.Percentage);
            var secondResolutionDateTimeFormat = Globalization.DateTimeFormat.longTimePattern;
            var minuteResolutionDateTimeFormat = {
                month: "short",
                hour: "numeric",
                minute: "2-digit",
                second: "2-digit"
            };
            var daysOfMonthResolutionDateTimeFormat = {
                month: "long",
                weekday: "long"
            };
            var yearResolutionDateTimeFormat = Globalization.DateTimeFormat.fullDateTimePattern;
            var xAxisMultiFormatDateTimeOptions = [, secondResolutionDateTimeFormat, minuteResolutionDateTimeFormat, , , daysOfMonthResolutionDateTimeFormat, , yearResolutionDateTimeFormat];
            this.lineChartVM.xAxis.formatOptions(Globalization.DateTimeFormat.shortTimePattern);
            this.lineChartVM.xAxis.rotateLabel(-45);
            this.lineChartVM.xAxis.labelPadding(100);
            this.lineChartVM.yAxis.formatOptions(yAxisNumberFormatOptions);
            var xSliderSecondResolutionDateTimeFormat = {
                minute: "2-digit",
                second: "2-digit"
            };
            var xSliderMinuteResolutionDateTimeFormat = Globalization.DateTimeFormat.longDatePattern;
            var xSliderMultiFormatDateTimeOptions = [, xSliderSecondResolutionDateTimeFormat, xSliderMinuteResolutionDateTimeFormat, , , daysOfMonthResolutionDateTimeFormat, , yearResolutionDateTimeFormat];
            this.lineChartVM.xAxis.xSliderFormatOptions(xSliderMultiFormatDateTimeOptions);
            this._addMetricRulesWithOptions();
            this.lineChartVM.interactionBehavior(FxChart.InteractionBehavior.XSlider_Off | FxChart.InteractionBehavior.ChartArea_Off);
            ko.reactor(container, function () {
                if (!_this.vmCpuDataSeries())
                    return;
                var allChartSeries = [];
                var chartSeries = new FxChart.Series();
                chartSeries.name(_this.vmCpuDataSeries().Name);
                var cpuSeriesValues = _this.vmCpuDataSeries().DataPoints.map(function (dataPoint) {
                    return new FxChart.ChartItem(new Date(dataPoint.Date), dataPoint.Value);
                });
                chartSeries.values(cpuSeriesValues);
                allChartSeries.push(chartSeries);
                _this.lineChartVM.series(allChartSeries);
            });
            ko.reactor(container, function () {
                var level = _this._dataContext.proxyRequestLevel;
                if (_this.vmId() && !_this.vmCpuDataSeries() && level() === 2) {
                    var promise = Helpers.callArmProxy(_this.vmId(), "VMUtilization", "GET");
                    promise.then(function (vmCpuDataSeries) {
                        _this.vmCpuDataSeries(vmCpuDataSeries);
                        level(3);
                    });
                }
            });
        }
        LineChartDateBasedPartViewModel.prototype.onInputsSet = function (inputs) {
            this.vmId(inputs.id);
            this.vmCpuDataSeries(null);
            return Q();
        };
        LineChartDateBasedPartViewModel.prototype.dispose = function () {
        };
        LineChartDateBasedPartViewModel.prototype._addMetricRulesWithOptions = function () {
            var metricNumberFormatOptions = { minimumFractionDigits: 3, maximumFractionDigits: 4 };
            var metricRule1 = new FxChart.MetricRule({
                scope: 0,
                metrics: ko.observableArray([])
            });
            var metricRule1_metric2 = new FxChart.MetricRuleMetric({
                aggregationScope: 0,
                aggregationType: 3,
                title: "Max",
                unit: "%"
            });
            var metricRule1_metric3 = new FxChart.MetricRuleMetric({
                aggregationScope: 0,
                aggregationType: 4,
                title: "Average"
            });
            metricRule1.metrics([metricRule1_metric2, metricRule1_metric3]);
            this.lineChartVM.metricsRules([metricRule1]);
        };
        LineChartDateBasedPartViewModel.prototype._addLegacyMetricRules = function () {
        };
        return LineChartDateBasedPartViewModel;
    }());
    exports.LineChartDateBasedPartViewModel = LineChartDateBasedPartViewModel;
});
