define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var ArmHelpers = Common.Helpers;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    var SubscriptionsOverviewGridPartViewModel = (function () {
        function SubscriptionsOverviewGridPartViewModel(container, initialState, dataContext) {
            var _this = this;
            this.billingPeriod = ko.observable(null);
            this.billingIcon = MsPortalFx.Base.Images.Polychromatic.BillingHub();
            this.remainingCreditsText = ko.observable("");
            this._monitorBillingPeriodDropDown = ko.observable(false);
            this.isCurrentMonth = ko.observable(false);
            this.location = ko.observable("local");
            this._overviewItems = ko.observableArray([]);
            this._container = container;
            this._dataContext = dataContext;
            var gridExtensions = FxGridExtensions.SelectableRow | FxGridExtensions.ContextMenuShortcut;
            this._dataQueryView = this._dataContext.sharedContext.userCreditsManager.listUserCreditsQuery.createView(container, {
                interceptNotFound: false
            });
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1
                }
            };
            var itemsExtended = this._overviewItems.mapInto(container, function (lifetime, item) {
                if (!_this._monitorBillingPeriodDropDown())
                    return item;
                console.log('Using billing start: ' + _this.billingPeriod().StartDate);
                return MsPortalFx.extend2(item, {
                    commandGroup: "SubscriptionGridCommands",
                    BillingPeriod: _this.billingPeriod
                });
            });
            this.subscriptionsGrid = new FxGrid.ViewModel(container, itemsExtended, gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "SubscriptionId",
                    name: ko.observable("Subscription Id"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "SubscriptionName",
                    name: ko.observable("Name"),
                    activatable: ko.observable(true)
                },
                {
                    itemKey: "TotalCostString",
                    name: ko.observable("Total Cost"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "OfferCreditsString",
                    name: ko.observable("Offer Credits"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "TaxAmountString",
                    name: ko.observable("Tax Amount"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "BillableCostString",
                    name: ko.observable("Billable Cost"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "CreditBalanceString",
                    name: ko.observable("User Credits"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "BillAmountString",
                    name: ko.observable("Bill Amount"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
            ];
            this.subscriptionsGrid.columns = ko.observableArray(basicColumns);
            this.subscriptionsGrid.showHeader = true;
            this.subscriptionsGrid.summary = ko.observable("Summary");
            this.subscriptionsGrid.noRowsMessage("No items found");
        }
        SubscriptionsOverviewGridPartViewModel.prototype.onInputsSet = function (inputs) {
            var _this = this;
            this.subscriptionsCategory = inputs.subscriptionsCategory;
            this._monitorBillingPeriodDropDown(inputs.monitorBillingPeriodDropDown.toLowerCase() === 'true');
            var subIds = this._dataContext.sharedContext.subscriptionsManager.subscriptionIdList;
            if (this.subscriptionsCategory === 'Owned') {
                this._container.partTitle("Active subscriptions that you own");
                this._dataQueryView.fetch({
                    subscriptionId: subIds[0],
                    location: this.location()
                });
                this.isCurrentMonth(true);
            }
            else if (this.subscriptionsCategory === 'Associated') {
                this._container.partTitle("Other subscriptions that you're associated with");
                this.isCurrentMonth(false);
            }
            if (!this._monitorBillingPeriodDropDown()) {
                this.getRemainingCredits();
                this.subscriptionsGrid.loading(true);
                return this._dataContext.sharedContext.billingOverviewManager.getBillingOverviews(this.subscriptionsCategory, subIds).then(function (overviews) {
                    _this._overviewItems(overviews);
                    _this.subscriptionsGrid.loading(false);
                });
            }
            else {
                this._dataContext.selectedBillingPeriod.subscribe(this._container, this._onBillingPeriodChanged.bind(this));
                return this._onBillingPeriodChanged(this._dataContext.selectedBillingPeriod());
            }
        };
        SubscriptionsOverviewGridPartViewModel.prototype._onBillingPeriodChanged = function (selectedBillingPeriod) {
            var _this = this;
            this.billingPeriod(selectedBillingPeriod);
            this.isCurrentMonth(false);
            this._overviewItems([]);
            if (!selectedBillingPeriod)
                return Q();
            if (selectedBillingPeriod.IsCurrent != null && selectedBillingPeriod.IsCurrent) {
                this.isCurrentMonth(selectedBillingPeriod.IsCurrent);
                this.getRemainingCredits();
            }
            this.subscriptionsGrid.loading(true);
            var subIds = this._dataContext.sharedContext.subscriptionsManager.subscriptionIdList;
            return this._dataContext.sharedContext.billingOverviewManager.getBillingHistory(this.subscriptionsCategory, selectedBillingPeriod.StartDate, subIds).then(function (overviews) {
                _this._overviewItems(overviews);
                _this.subscriptionsGrid.loading(false);
            });
        };
        SubscriptionsOverviewGridPartViewModel.prototype.getRemainingCredits = function () {
            var _this = this;
            var remainingCredits = new Array();
            this._dataQueryView.items.subscribe(this._container, function (userCreditsList) {
                userCreditsList.forEach(function (val, index) {
                    remainingCredits.push(val.RemainingCredits().toFixed(2).toString() + " " + val.ISOCurrencySymbol());
                });
                _this.remainingCreditsText(remainingCredits.join(", "));
            });
        };
        return SubscriptionsOverviewGridPartViewModel;
    }());
    exports.SubscriptionsOverviewGridPartViewModel = SubscriptionsOverviewGridPartViewModel;
});
