var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var ArmHelpers = Common.Helpers;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    var UsageAndQuotaStatusGridPartViewModel = (function (_super) {
        __extends(UsageAndQuotaStatusGridPartViewModel, _super);
        function UsageAndQuotaStatusGridPartViewModel(container, initialState, dataContext) {
            _super.call(this);
            this.billingPeriod = ko.observable(null);
            this.billingIcon = MsPortalFx.Base.Images.Polychromatic.BillingHub();
            this.remainingCreditsText = ko.observable("");
            this._monitorBillingPeriodDropDown = ko.observable(false);
            this.isCurrentMonth = ko.observable(false);
            this.subscriptionIdIn = ko.observable();
            this.subscriptionIdList = ko.observableArray([]);
            this.periodList = ko.observableArray([]);
            this.allProviderList = ko.observableArray([]);
            this.allResourceList = ko.observableArray([]);
            this.location = ko.observable("local");
            this.title("Quota Status");
            this._container = container;
            this._dataContext = dataContext;
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1
                }
            };
            this.quotaStatusGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "SubscriptionId",
                    name: ko.observable("Subscription Id"),
                    activatable: ko.observable(false),
                },
                {
                    itemKey: "SubscriptionName",
                    name: ko.observable("Subscription Name"),
                    activatable: ko.observable(false)
                },
                {
                    itemKey: "OkStatus",
                    name: ko.observable("OK"),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: "<div>" +
                            "<span style='color: forestgreen' data-bind='text: value'></span" +
                            "</div>",
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "WarningStatus",
                    name: ko.observable("Warning"),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: "<div>" +
                            "<span style='color: orange' data-bind='text: value'></span" +
                            "</div>",
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "CriticalStatus",
                    name: ko.observable("Critical"),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: "<div>" +
                            "<span style='color: red' data-bind='text: value'></span" +
                            "</div>",
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
            ];
            this.quotaStatusGrid.columns = ko.observableArray(basicColumns);
            this.quotaStatusGrid.showHeader = true;
            this.quotaStatusGrid.summary = ko.observable("Summary");
            this.quotaStatusGrid.noRowsMessage("No items found");
        }
        UsageAndQuotaStatusGridPartViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            var subscriptionsDict = {};
            return this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                subscriptions.map(function (s) {
                    subscriptionsDict[s.subscriptionId] = s.displayName;
                });
                _this.subscriptionIdList(Object.keys(subscriptionsDict));
                _this.subscriptionIdIn(_this.subscriptionIdList().first());
                _this._dataContext.sharedContext.usageAndQuotaDataManager.getAzSQuotaFilters(_this.subscriptionIdIn(), _this.subscriptionIdList()).then(function (filters) {
                    var resourceList = [];
                    var providers = Object.keys(filters.Resources);
                    _this.allProviderList(providers);
                    Object.keys(filters.Resources).forEach(function (key) {
                        resourceList = resourceList.concat(filters.Resources[key]);
                    });
                    _this.allResourceList(resourceList);
                    var periods = [];
                    filters.BillingCyclePeriods.map(function (mr) {
                        periods.push(mr);
                    });
                    _this.periodList(periods);
                    var input = {
                        SubscriptionIds: _this.subscriptionIdList(),
                        QuotaProviderList: _this.allProviderList(),
                        QuotaResourceNames: _this.allResourceList(),
                        QuotaPeriod: { StartDate: _this.periodList().first().StartDate, EndDate: _this.periodList().first().EndDate, IsCurrent: true },
                    };
                    _this._dataContext.sharedContext.usageAndQuotaDataManager.getAzSSnapInView(_this.subscriptionIdList().first(), input).then(function (quotaRecords) {
                        var transformedQuotas = quotaRecords.map(function (c) {
                            return $.extend({}, c, {
                                SubscriptionName: subscriptionsDict[c.SubscriptionId],
                                OkStatus: c.AzureStackCollectiveQuotaStatus.OK,
                                WarningStatus: c.AzureStackCollectiveQuotaStatus.Warning,
                                CriticalStatus: c.AzureStackCollectiveQuotaStatus.Critical,
                            });
                        });
                        _this.quotaStatusGrid.items(transformedQuotas);
                        _this.quotaStatusGrid.loading(false);
                    });
                });
            });
        };
        return UsageAndQuotaStatusGridPartViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UsageAndQuotaStatusGridPartViewModel = UsageAndQuotaStatusGridPartViewModel;
});
