var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    var FxControls = MsPortalFx.ViewModels.Controls;
    var UsageHistoryByResourcesGridBladeViewModel = (function (_super) {
        __extends(UsageHistoryByResourcesGridBladeViewModel, _super);
        function UsageHistoryByResourcesGridBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionIdIn = ko.observable();
            this.subscriptionIdList = ko.observableArray([]);
            this.billingPeriodIn = ko.observable();
            this.subscriptionId = ko.observable();
            this.billingPeriod = ko.observable();
            this.meteredResourceId = ko.observable();
            this.location = ko.observable("local");
            this.totalBillableCost = ko.observable(0);
            this.currency = ko.observable();
            this.billingIcon = MsPortalFx.Base.Images.Polychromatic.BillingHub();
            this.title = ko.observable("Costs by Metered Resource");
            this.icon = ko.observable(MsPortalFx.Base.Images.Clock());
            this._container = container;
            this._dataContext = dataContext;
            this._initFiltersAndButtonsSection(container);
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1
                }
            };
            this.resourcesUsageGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "MeteredResourceDisplayName",
                    name: ko.observable("Metered Resource"),
                    activatable: ko.observable(false)
                },
                {
                    itemKey: "ResourceCount",
                    name: ko.observable("Resource Count"),
                    activatable: ko.observable(true)
                },
                {
                    itemKey: "ConsumedUnitsDisplay",
                    name: ko.observable("Consumed Units"),
                    activatable: ko.observable(false)
                },
                {
                    itemKey: "CostString",
                    name: ko.observable("Cost"),
                },
                {
                    itemKey: "BillableUnitsDisplay",
                    name: ko.observable("Billable Units"),
                    activatable: ko.observable(false)
                },
                {
                    itemKey: "BillableCostString",
                    name: ko.observable("Billable Cost"),
                },
            ];
            this.resourcesUsageGrid.columns = ko.observableArray(basicColumns);
            this.resourcesUsageGrid.showHeader = true;
            this.resourcesUsageGrid.summary = ko.observable("Summary");
            this.resourcesUsageGrid.noRowsMessage("No items found");
            this.resourcesUsageGrid.items.subscribe(container, function (usageItems) {
                if (usageItems.length > 0) {
                    var totalCostValue = usageItems.map(function (x) { return x.BillableCost; }).reduce(function (total, c) { return total + c; });
                    _this.totalBillableCost(_this._dataContext.getFormattedCost(totalCostValue));
                    _this.currency(usageItems[0].Currency);
                }
                else {
                    _this.totalBillableCost(0);
                    _this.currency("");
                }
            });
            this.subscriptionId.subscribe(container, function (subscriptionId) {
                _this.meteredResourcesDropDown.disabled(true);
                _this.meteredResourcesDropDown.loading(true);
                _this.billingPeriodsDropDown.disabled(true);
                _this.billingPeriodsDropDown.loading(true);
                _this.meteredResourcesDropDown.options([{
                        text: ko.observable("Loading..."),
                        value: -2,
                        disabled: ko.observable(true)
                    }]);
                _this.billingPeriodsDropDown.options([{
                        text: ko.observable("Loading..."),
                        value: null,
                        disabled: ko.observable(true)
                    }]);
                if (!subscriptionId) {
                    _this.meteredResourcesDropDown.loading(false);
                    _this.billingPeriodsDropDown.loading(false);
                    return;
                }
                var q1 = _this._dataContext.sharedContext.billingOverviewManager.getMeteredResources(subscriptionId).then(function (meteredResources) {
                    _this.meteredResourceDefsDict = {};
                    meteredResources.forEach(function (mr) {
                        _this.meteredResourceDefsDict[mr.Id] = mr;
                    });
                    var resourcesDropdownValues = meteredResources.map(function (mr) {
                        return {
                            text: ko.observable(mr.MeteredResourceDisplayName),
                            value: mr.Id,
                            disabled: ko.observable(false)
                        };
                    });
                    resourcesDropdownValues.unshift({
                        text: ko.observable("All metered resources"),
                        value: -1,
                        disabled: ko.observable(false)
                    });
                    _this.meteredResourcesDropDown.options(resourcesDropdownValues);
                    _this.meteredResourcesDropDown.value(-1);
                    _this.meteredResourcesDropDown.disabled(false);
                });
                var q2 = _this._dataContext.sharedContext.billingOverviewManager.getBillingPeriods(_this.subscriptionIdList()).then(function (billingPeriods) {
                    var billingPeriodDropdownValues = billingPeriods.map(function (bp) {
                        return {
                            text: ko.observable(bp.Label),
                            value: bp,
                            disabled: ko.observable(false),
                        };
                    });
                    billingPeriodDropdownValues.push({
                        text: ko.observable("Please select a Billing Period"),
                        value: null,
                        disabled: ko.observable(false)
                    });
                    _this.billingPeriodsDropDown.options(billingPeriodDropdownValues);
                    if (_this.billingPeriodIn()) {
                        var periodToSelect = billingPeriods.first(function (bp) { return bp.StartDate == _this.billingPeriodIn().StartDate; });
                        _this.billingPeriodsDropDown.value(periodToSelect);
                    }
                    else {
                        var currentBP = billingPeriods.first(function (bp) { return bp.IsCurrent; });
                        _this.billingPeriodsDropDown.value(currentBP);
                    }
                    _this.billingPeriodsDropDown.disabled(false);
                });
                Q.all([q1, q2]).then(function () {
                    _this._onApplyButtonClicked();
                });
            });
            this.isValid = ko.computed(container, function () {
                return _this.subscriptionId() && _this.meteredResourceId() && _this.billingPeriod();
            });
            var _disabledOption = ko.pureComputed(function () { return !_this.isValid(); });
            this.applyFiltersButton.disabled(_disabledOption());
            this.downloadHistoryButton.disabled(_disabledOption());
        }
        UsageHistoryByResourcesGridBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.subscriptionIdIn(inputs.subscriptionId);
            this.billingPeriodIn(inputs.billingPeriod);
            this.subscriptionIdList(this._dataContext.sharedContext.subscriptionsManager.subscriptionIdList);
            return this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                var dropdownValues = subscriptions.map(function (s) {
                    return {
                        text: ko.observable(s.uniqueDisplayName),
                        value: s.subscriptionId,
                        disabled: ko.observable(false)
                    };
                });
                dropdownValues.unshift({
                    text: ko.observable("Select a subscription..."),
                    value: null,
                    disabled: ko.observable(false)
                });
                _this.subscriptionsDropDown.options(dropdownValues);
                if (_this.subscriptionIdIn()) {
                    _this.subscriptionsDropDown.value(_this.subscriptionIdIn());
                }
                else {
                    _this.subscriptionsDropDown.value(null);
                }
            });
        };
        UsageHistoryByResourcesGridBladeViewModel.prototype._initFiltersAndButtonsSection = function (container) {
            var _this = this;
            var subscriptionDropDownOptions = {
                label: ko.observable("Subscription Id"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Subscription Id for listing cost history"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.subscriptionsDropDown = new FxDropDown.ViewModel(container, subscriptionDropDownOptions);
            this.subscriptionsDropDown.value.subscribe(container, function (newSubscriptionId) {
                _this.subscriptionId(newSubscriptionId);
            });
            var meteredResourceDropDownOptions = {
                label: ko.observable("Metered Resource"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Metered Resource for which the cost history should be shown"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: -2 }])
            };
            this.meteredResourcesDropDown = new FxDropDown.ViewModel(container, meteredResourceDropDownOptions);
            this.meteredResourcesDropDown.value.subscribe(container, function (meteredResourceId) {
                _this.meteredResourceId(meteredResourceId);
            });
            var billingPeriodDropDownOptions = {
                label: ko.observable("Billing Period"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Billing Period for which the cost history should be shown"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.billingPeriodsDropDown = new FxDropDown.ViewModel(container, billingPeriodDropDownOptions);
            this.billingPeriodsDropDown.value.subscribe(container, function (billingPeriod) {
                _this.billingPeriod(billingPeriod);
            });
            this.applyFiltersButton = new FxControls.SimpleButton.ViewModel(container, {
                onClick: this._onApplyButtonClicked.bind(this),
                text: "Apply",
                primary: true,
            });
            this.downloadHistoryButton = new FxControls.SimpleButton.ViewModel(container, {
                onClick: this._onDownloadButtonClicked.bind(this),
                text: "Download",
                primary: true,
            });
            var column1 = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(0),
                children: ko.observableArray([
                    this.subscriptionsDropDown,
                    this.meteredResourcesDropDown,
                ])
            });
            var column2 = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(0),
                children: ko.observableArray([
                    this.billingPeriodsDropDown,
                ])
            });
            this.filtersSection = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([
                    column1, column2
                ])
            });
        };
        UsageHistoryByResourcesGridBladeViewModel.prototype._onApplyButtonClicked = function () {
            var _this = this;
            var subscriptionId = this.subscriptionId && this.subscriptionId();
            var subIds = this._dataContext.sharedContext.subscriptionsManager.subscriptionIdList;
            if (!subscriptionId || subscriptionId === "-") {
                this.resourcesUsageGrid.items([]);
                return;
            }
            var billingPeriod = this.billingPeriod && this.billingPeriod();
            if (!billingPeriod) {
                this.resourcesUsageGrid.items([]);
                return;
            }
            var meteredResourceId = this.meteredResourceId && this.meteredResourceId();
            this.resourcesUsageGrid.loading(true);
            var startDate = billingPeriod.StartDate;
            var endDate = billingPeriod.EndDate;
            this._dataContext.sharedContext.billingOverviewManager.getConsumptionForBillingPeriod(subscriptionId, subIds, startDate, endDate).then(function (usageRecords) {
                var mappedItems = usageRecords.filter(function (item) { return meteredResourceId === -1 || meteredResourceId === item.MeteredResourceId; }).map(function (item) {
                    var mrDef = _this.meteredResourceDefsDict[item.MeteredResourceId];
                    var unitDisplayName = mrDef != null ? mrDef.UnitDisplayName : '';
                    return $.extend({}, item, {
                        CostString: "{0} {1}".format(item.CurrencySymbol, item.Cost),
                        BillableCostString: "{0} {1}".format(item.CurrencySymbol, item.BillableCost),
                        ConsumedUnitsDisplay: "{0} {1}".format(item.Units, unitDisplayName),
                        BillableUnitsDisplay: "{0} {1}".format(unitDisplayName == '' ? '1' : item.BillableUnits, unitDisplayName),
                    });
                });
                _this.resourcesUsageGrid.items(mappedItems);
                _this.resourcesUsageGrid.loading(false);
            });
        };
        UsageHistoryByResourcesGridBladeViewModel.prototype._onDownloadButtonClicked = function () {
            console.log('Download Button has not been implemented yet!');
        };
        return UsageHistoryByResourcesGridBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UsageHistoryByResourcesGridBladeViewModel = UsageHistoryByResourcesGridBladeViewModel;
});
