var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "ClientResources"], function (require, exports, ClientResources) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var AddCloudServiceCustomerFormBladeViewModel = (function (_super) {
        __extends(AddCloudServiceCustomerFormBladeViewModel, _super);
        function AddCloudServiceCustomerFormBladeViewModel(container, initialState, dataContext) {
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.cspCustomerId = ko.observable();
            this.title = ko.observable("Customer User Details");
            this.icon = ko.observable(MsPortalFx.Base.Images.Person());
            this._container = container;
            this._dataContext = dataContext;
            this._initializeFormFields(container);
            this._setupCommandBar();
        }
        AddCloudServiceCustomerFormBladeViewModel.prototype._initializeFormFields = function (container) {
            var firstNameOptions = {
                label: ko.observable("First Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.firstNameTxField = new FxForms.TextBox.ViewModel(container, firstNameOptions);
            var lastNameOptions = {
                label: ko.observable("Last Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.lastNameTxField = new FxForms.TextBox.ViewModel(container, lastNameOptions);
            var displayNameOptions = {
                label: ko.observable("Display Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.displayNameTxField = new FxForms.TextBox.ViewModel(container, displayNameOptions);
            var passwordOptions = {
                label: ko.observable("Password"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation("^[a-zA-Z0-9!@#$&()\\-`.+,/\"]*$", "Invalid"),
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.passwordTxField = new FxForms.PasswordBox.ViewModel(container, passwordOptions);
            var emailOptions = {
                label: ko.observable("Email Alias"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation(/^[a-zA-Z0-9\-\.]+$/.source, "Invalid"),
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.emailTxField = new FxForms.TextBox.ViewModel(container, emailOptions);
            var sectionOptions = {
                children: ko.observableArray([
                    this.firstNameTxField,
                    this.lastNameTxField,
                    this.displayNameTxField,
                    this.passwordTxField,
                    this.emailTxField,
                ])
            };
            this.generalSection = new FxForms.Section.ViewModel(container, sectionOptions);
        };
        AddCloudServiceCustomerFormBladeViewModel.prototype._setupCommandBar = function () {
            var _this = this;
            var saveButton = new MsPortalFx.ViewModels.Toolbars.CommandButton({
                label: ClientResources.Commands.save,
                icon: MsPortalFx.Base.Images.Save(),
                command: {
                    canExecute: ko.observable(true),
                    execute: function (context) {
                        return _this._container.form.triggerValidation().then(function (validationPassed) {
                            if (validationPassed) {
                                return _this._onSaveChanges();
                            }
                            return null;
                        });
                    },
                }
            });
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([saveButton]);
        };
        AddCloudServiceCustomerFormBladeViewModel.prototype._onSaveChanges = function () {
            var _this = this;
            var cspUserInfo = {
                SubscriptionId: this.subscriptionId(),
                CustomerProfileId: this.cspCustomerId(),
                CustomerTenantId: this.cspCustomerId(),
                FirstName: this.firstNameTxField.value(),
                LastName: this.lastNameTxField.value(),
                DisplayName: this.displayNameTxField.value(),
                Password: this.passwordTxField.value(),
                EmailAlias: this.emailTxField.value(),
            };
            return this._dataContext.cspDataManager.addCspUser(this.subscriptionId(), cspUserInfo)
                .then(function (data) {
                if (data != null) {
                    _this._dataContext.cspDataManager.cspUsersQuery.refreshAll();
                    _this._container.closeCurrentBlade();
                }
            });
        };
        AddCloudServiceCustomerFormBladeViewModel.prototype.onInputsSet = function (inputs) {
            this.subscriptionId(inputs.subscriptionId);
            this.cspCustomerId(inputs.cspCustomerId);
            return Q();
        };
        return AddCloudServiceCustomerFormBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.AddCloudServiceCustomerFormBladeViewModel = AddCloudServiceCustomerFormBladeViewModel;
});
