var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../_generated/BladeReferences"], function (require, exports, BladeReferences) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var CloudServiceCustomerProfilesBladeViewModel = (function (_super) {
        __extends(CloudServiceCustomerProfilesBladeViewModel, _super);
        function CloudServiceCustomerProfilesBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.title("Cloud Service Customer Profiles");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.cspDataManager.cspCustomerProfilesQuery.createView(container, {
                interceptNotFound: false
            });
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                },
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.cspCustomerProfilesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "TenantId",
                    name: ko.observable("Microsoft Id"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "FirstName",
                    name: ko.observable("First Name"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "CompanyName",
                    name: ko.observable("Company Name"),
                    width: ko.observable("50px"),
                }
            ];
            this.cspCustomerProfilesGrid.columns = ko.observableArray(basicColumns);
            this.cspCustomerProfilesGrid.showHeader = true;
            this.cspCustomerProfilesGrid.summary = ko.observable("Summary");
            this.cspCustomerProfilesGrid.noRowsMessage("No items found");
            this._dataQueryView.items.subscribe(container, function (custProfiles) {
                _this.cspCustomerProfilesGrid.items(custProfiles);
                if (custProfiles.length > 0)
                    _this.commandBar.setItems([]);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.cspCustomerProfilesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        CloudServiceCustomerProfilesBladeViewModel.prototype._setupCommandBar = function () {
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([]);
        };
        CloudServiceCustomerProfilesBladeViewModel.prototype._createAddCustomerProfileButton = function () {
            var _this = this;
            this.customerTypeRadioButton = new MsPortalFx.ViewModels.Forms.OptionsGroup.ViewModel(this._container, {
                options: ko.observableArray([
                    { text: ko.observable("New"), value: "New" },
                    { text: ko.observable("Existing"), value: "Existing" }
                ]),
                radioButtonStyle: true
            });
            var formDialog = new Dialogs.FormDialog("Select Customer Type");
            formDialog.row1column1 = this.customerTypeRadioButton;
            var button = new FxToolbars.DialogButton({
                label: "Create",
                icon: MsPortalFx.Base.Images.Add(),
                dialogOptions: formDialog,
                command: {
                    execute: function () {
                        if (_this.customerTypeRadioButton.value() == "New") {
                            return _this._container.openBlade(new BladeReferences.AddCloudServiceCustomerProfileBladeReference({
                                marketDetails: _this.marketDetails
                            }));
                        }
                        else if (_this.customerTypeRadioButton.value() == "Existing") {
                            return _this._container.openBlade(new BladeReferences.OnboardExistingCloudServiceCustomerProfileBladeReference());
                        }
                    },
                    canExecute: ko.computed(this._container, function () {
                        return _this.marketDetails != null;
                    }),
                }
            });
            return button;
        };
        CloudServiceCustomerProfilesBladeViewModel.prototype._createRefreshButton = function () {
            var _this = this;
            var refreshButton = new FxToolbars.CommandButton({
                label: "Refresh",
                icon: MsPortalFx.Base.Images.Refresh(),
                command: {
                    canExecute: ko.observable(true),
                    execute: function () {
                        return _this._dataQueryView.refresh();
                    }
                }
            });
            return refreshButton;
        };
        CloudServiceCustomerProfilesBladeViewModel.prototype.onInputsSet = function () {
            var _this = this;
            return this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                var subscriptionId = "-";
                if (subscriptions.length > 0)
                    subscriptionId = subscriptions.first().subscriptionId;
                _this._dataQueryView.fetch({
                    subscriptionId: subscriptionId,
                });
                _this._dataContext.cspDataManager.getCspMarketDetails(subscriptionId)
                    .then(function (data) {
                    _this.marketDetails = data;
                    _this._addCustomerProfileButton = _this._createAddCustomerProfileButton();
                    _this.commandBar.setItems([_this._addCustomerProfileButton]);
                });
            });
        };
        return CloudServiceCustomerProfilesBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CloudServiceCustomerProfilesBladeViewModel = CloudServiceCustomerProfilesBladeViewModel;
});
