var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var ArmHelpers = Common.Helpers;
    var CloudServiceSubscriptionDetailsBladeViewModel = (function (_super) {
        __extends(CloudServiceSubscriptionDetailsBladeViewModel, _super);
        function CloudServiceSubscriptionDetailsBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.originalQuantity = ko.observable(0);
            this.cspSubscription = ko.observable();
            this.title("Cloud Subscriptions");
            this._container = container;
            this._dataContext = dataContext;
            this._dataEntityView = dataContext.cspDataManager.cspSubscriptionEntity.createView(container);
            this._dataEntityView.item.subscribe(container, function (cspSub) {
                _this.cspSubscription(cspSub);
            });
            ko.reactor(container, function () {
                if (_this.cspSubscription()) {
                    var x = _this.cspSubscription();
                    _this.nameTxField.value(x.FriendlyName());
                    _this.licensesSliderControl.value(x.Quantity());
                    _this.licensesSliderControl.max(x.MaxQuantity());
                    _this.licensesSliderControl.min(x.MinQuantity());
                    if (_this.cspSubscription().Status() == "Suspended")
                        _this.purchaseLicensesButton.disabled(true);
                }
            });
            this._initializeFormFields(container);
            this._setupCommandBar();
        }
        CloudServiceSubscriptionDetailsBladeViewModel.prototype._setupCommandBar = function () {
            var _this = this;
            this.purchaseLicensesButton = new MsPortalFx.ViewModels.Toolbars.DialogButton();
            this.purchaseLicensesButton.label("Purchase");
            this.purchaseLicensesButton.icon(MsPortalFx.Base.Images.Plus());
            this.purchaseLicensesButton.dialogOptions = new MsPortalFx.ViewModels.Dialogs.MessageBox("", "Are you sure you want to purchase ?", 4);
            this.purchaseLicensesButton.command = {
                canExecute: ko.pureComputed(function () { return _this.licensesSliderControl && _this.licensesSliderControl.value() !== _this.originalQuantity(); }),
                execute: function (context) {
                    if (context == 6) {
                        var op_1;
                        var dataManager_1 = _this._dataContext.cspDataManager;
                        _this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                            if (subscriptions.length > 0)
                                var subIds = subscriptions.map(function (s) { return s.subscriptionId; });
                            return _this._dataContext.cspDataManager.getCspEnabledSubIds(subIds).then(function (cspSubscriptionsIds) {
                                _this.subscriptionId(cspSubscriptionsIds.first());
                                op_1 = dataManager_1.purchaseMoreLicenses(_this.subscriptionId(), _this.cspSubscription().Id(), _this.licensesSliderControl.value(), cspSubscriptionsIds).then(function () {
                                    return Q.all([
                                        dataManager_1.cspSubscriptionEntity.refreshAll(),
                                        dataManager_1.cspSubscriptionsQuery.refreshAll(),
                                        _this._container.closeCurrentBlade()
                                    ]);
                                });
                            });
                        });
                        _this._container.operations.add(op_1, { blockUi: true });
                        return op_1;
                    }
                }
            };
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([this.purchaseLicensesButton]);
        };
        CloudServiceSubscriptionDetailsBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            return this._dataEntityView.fetch({
                subscriptionId: inputs.subscriptionId,
                cspSubscriptionId: inputs.cspSubscriptionId,
            });
        };
        CloudServiceSubscriptionDetailsBladeViewModel.prototype._initializeFormFields = function (container) {
            this.nameTxField = new FxForms.TextBox.ViewModel(container, {
                label: ko.observable("Cloud Service Name"),
                emptyValueText: ko.observable("Cloud Service Name"),
                readonly: true
            });
            var sliderOptions = {
                label: ko.observable("Number of licenses"),
                infoBalloonContent: ko.observable("Slide to purchase more licenses"),
                max: ko.observable(50),
                min: ko.observable(1),
                step: ko.observable(1),
                defaultValue: ko.observable(1)
            };
            this.licensesSliderControl = new FxForms.Slider.ViewModel(container, sliderOptions);
            var sectionOptions = {
                children: ko.observableArray([
                    this.nameTxField,
                    this.licensesSliderControl,
                ])
            };
            this.generalSection = new FxForms.Section.ViewModel(container, sectionOptions);
        };
        return CloudServiceSubscriptionDetailsBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CloudServiceSubscriptionDetailsBladeViewModel = CloudServiceSubscriptionDetailsBladeViewModel;
});
