var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../_generated/BladeReferences"], function (require, exports, BladeReferences) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var ArmHelpers = Common.Helpers;
    var CloudServiceUsersBladeViewModel = (function (_super) {
        __extends(CloudServiceUsersBladeViewModel, _super);
        function CloudServiceUsersBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.cspCustomerId = ko.observable();
            this.location = ko.observable("local");
            this.selectedUser = ko.pureComputed(function () {
                return _this.cloudServiceUsersGrid.selectableData.selectedItems().first();
            });
            this.title("Cloud Users");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.cspDataManager.cspUsersQuery.createView(container, {
                interceptNotFound: false
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1
                }
            };
            this.cloudServiceUsersGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Microsoft Id"),
                },
                {
                    itemKey: "FirstName",
                    name: ko.observable("First Name"),
                },
                {
                    itemKey: "LastName",
                    name: ko.observable("Last Name"),
                },
                {
                    itemKey: "DisplayName",
                    name: ko.observable("Display Name"),
                },
                {
                    itemKey: "UserPrincipalName",
                    name: ko.observable("User Principal Name"),
                },
            ];
            this.cloudServiceUsersGrid.columns = ko.observableArray(basicColumns);
            this.cloudServiceUsersGrid.showHeader = true;
            this.cloudServiceUsersGrid.summary = ko.observable("Summary");
            this.cloudServiceUsersGrid.noRowsMessage("No items found");
            this.cloudServiceUsersGrid.selectableData.selectedItems.subscribe(container, function (selectedItems) {
                if (!selectedItems || selectedItems.length === 0) {
                    return;
                }
            });
            this._dataQueryView.items.subscribe(container, function (cspUsers) {
                _this.subscriptionId(cspUsers[0].SubscriptionId());
                _this.cspCustomerId(cspUsers[0].CustomerProfileId());
                _this.cloudServiceUsersGrid.items(cspUsers);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.cloudServiceUsersGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        CloudServiceUsersBladeViewModel.prototype._setupCommandBar = function () {
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this._addCspUserButton = this._addCustomerUserButton();
            this._openButton = this._createOpenProfileButton();
            this.commandBar.setItems([this._addCspUserButton, this._openButton]);
        };
        CloudServiceUsersBladeViewModel.prototype._addCustomerUserButton = function () {
            var _this = this;
            var addButton = new FxToolbars.CommandButton({
                label: "Add",
                icon: MsPortalFx.Base.Images.Add(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.AddCloudServiceCustomerFormBladeReference({
                            subscriptionId: _this.subscriptionId(),
                            cspCustomerId: _this.cspCustomerId()
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return true;
                    }),
                }
            });
            return addButton;
        };
        CloudServiceUsersBladeViewModel.prototype._createOpenProfileButton = function () {
            var _this = this;
            var button = new FxToolbars.CommandButton({
                label: "Open",
                icon: MsPortalFx.Base.Images.Expand(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.AvailableCloudServiceLicensesBladeReference({
                            subscriptionId: _this.subscriptionId(),
                            cspCustomerId: _this.cspCustomerId(),
                            cspCustomerUserId: _this.selectedUser().Id(),
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return _this.selectedUser() != null;
                    }),
                }
            });
            return button;
        };
        CloudServiceUsersBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            return this._dataContext.sharedContext.subscriptionsManager.subscriptionsPromise.then(function (subscriptions) {
                var subscriptionId = "-";
                if (subscriptions.length > 0)
                    subscriptionId = subscriptions.first().subscriptionId;
                var args = {
                    subscriptionId: subscriptionId,
                    location: _this.location()
                };
                _this._dataQueryView.fetch(args);
            });
        };
        return CloudServiceUsersBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CloudServiceUsersBladeViewModel = CloudServiceUsersBladeViewModel;
});
