define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var BillingOverviewManager = (function () {
        function BillingOverviewManager() {
            this.Urls = {
                meteredResources: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/meteredResources",
                billingPeriods: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/billingPeriods",
                billingOverviews: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/list",
                billingHistory: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/listBillingHistory",
                userCurrentOverview: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/userCurrentOverview",
                subscriptionCurrentOverview: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/subscriptionCurrentOverview",
                subscriptionOverviewForBillingPeriod: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/subscriptionOverviewForBillingPeriod",
                subscriptionConsumptionForBillingPeriod: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/subscriptionConsumptionForBillingPeriod",
                currentCostBreakdown: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing/overviews/currentCostBreakdown"
            };
            this.subscriptionOverviewQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.SubscriptionOverviewModelType,
                sourceUri: ArmHelpers.getArmUriFormatter(this.Urls.billingOverviews, fxEnv.billingRpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.subscriptionOverviewEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.SubscriptionOverviewModelType,
                sourceUri: ArmHelpers.getArmUriFormatter("{id}", fxEnv.billingRpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
            this.billingOverviewEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.BillingOverviewType,
                sourceUri: ArmHelpers.getArmUriFormatter("{id}", "2015-11-01"),
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        BillingOverviewManager.prototype.getMeteredResources = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.meteredResources, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        BillingOverviewManager.prototype.getBillingPeriods = function (subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.billingPeriods, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIds);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        BillingOverviewManager.prototype.getBillingOverviews = function (category, subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.billingOverviews, false)(argsToUri);
            var deferred = Q.defer();
            var overviewsResult = [];
            var promises = [];
            var dataIn = {
                Category: category,
                SubscriptionIdList: subscriptionIds
            };
            var postData = ko.toJSON(dataIn);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData).then(function (overviewResponse) {
                overviewsResult = overviewsResult.concat(overviewResponse);
            });
            promises.push(promise);
            Q.all(promises).then(function () {
                deferred.resolve(overviewsResult);
            }, function (reason) {
                deferred.reject(reason);
            });
            return deferred.promise;
        };
        BillingOverviewManager.prototype.getBillingHistory = function (category, startDate, subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.billingHistory, false)(argsToUri);
            var deferred = Q.defer();
            var overviewsResult = [];
            var promises = [];
            var dataIn = {
                Category: category,
                StartDate: startDate,
                SubscriptionIdList: subscriptionIds
            };
            var postData = ko.toJSON(dataIn);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData).then(function (overviewResponse) {
                overviewsResult = overviewsResult.concat(overviewResponse);
            });
            promises.push(promise);
            Q.all(promises).then(function () {
                deferred.resolve(overviewsResult);
            }, function (reason) {
                deferred.reject(reason);
            });
            return deferred.promise;
        };
        BillingOverviewManager.prototype.getBillingUserOverview = function (subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.userCurrentOverview, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIds);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        BillingOverviewManager.prototype.getSubscriptionOverview = function (subscriptionIds) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.subscriptionCurrentOverview, false)(argsToUri);
            var postData = ko.toJSON(subscriptionIds);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        BillingOverviewManager.prototype.getSubscriptionOverviewForBillingPeriod = function (subscriptionIds, startDate) {
            var argsToUri = {
                subscriptionId: subscriptionIds[0],
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.subscriptionOverviewForBillingPeriod, false)(argsToUri);
            var dataIn = {
                StartDate: startDate,
                SubscriptionIdList: subscriptionIds
            };
            var postData = ko.toJSON(dataIn);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        BillingOverviewManager.prototype.getConsumptionForBillingPeriod = function (selectedSubscription, subscriptionIds, startDate, endDate) {
            var argsToUri = {
                subscriptionId: selectedSubscription,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.Urls.subscriptionConsumptionForBillingPeriod, false)(argsToUri);
            var dataIn = {
                StartDate: startDate,
                EndDate: endDate,
                SubscriptionIdList: subscriptionIds
            };
            var postData = ko.toJSON(dataIn);
            var promise = Helpers.callArm(uriSegment, "POST", rpApiVersion, postData);
            return promise;
        };
        BillingOverviewManager.prototype.getCostBreakdownForCurrentBillingCycle = function (subscriptionId) {
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.currentCostBreakdown, false)({
                subscriptionId: subscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + rpApiVersion;
            var q = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return q;
        };
        return BillingOverviewManager;
    }());
    exports.BillingOverviewManager = BillingOverviewManager;
});
